Module encryption

Module encryption 

Encryption algorithm, key material parsing, and request header handling.

Structs

DecodedEncryptionKey
Decoded fixed-size encryption key material.
EncryptionKey
Encryption key material for append/read operations.
EncryptionKeyLengthError

Enums

EncryptionAlgorithm
Encryption algorithm.
EncryptionSpec
Resolved encryption spec after combining stream metadata with the encryption key material, if any.
EncryptionSpecResolutionError

Statics

S2_ENCRYPTION_KEY_HEADER