ReadLimit

Enum ReadLimit 

pub enum ReadLimit {
    Unbounded,
    Count(usize),
    Bytes(usize),
    CountOrBytes(CountOrBytes),
}

Variants



Unbounded



Count(usize)



Bytes(usize)



CountOrBytes(CountOrBytes)

Implementations

Source

impl ReadLimit

pub fn is_unbounded(&self) -> bool

pub fn is_bounded(&self) -> bool

pub fn from_count_and_bytes(count: Option<usize>, bytes: Option<usize>) -> Self

pub fn count(&self) -> Option<usize>

pub fn bytes(&self) -> Option<usize>

pub fn into_allowance(self, max: CountOrBytes) -> CountOrBytes

pub fn allow(&self, additional_count: usize, additional_bytes: usize) -> bool

pub fn deny(&self, additional_count: usize, additional_bytes: usize) -> bool

pub fn remaining( &self, consumed_count: usize, consumed_bytes: usize, ) -> EvaluatedReadLimit

Given the amount of records already consumed, generate a new ReadLimit representing the remaining limit, or none if the limit has been met.