Module encryption

Module encryption 

Encryption algorithm, key material parsing, and request header handling.

Structs

DecodedEncryptionKey
Decoded fixed-size customer-supplied encryption key material.
EncryptionKey
Customer-supplied encryption key material for append/read operations.
EncryptionKeyLengthError

Enums

EncryptionAlgorithm
Encryption algorithm.
EncryptionSpec
Resolved encryption spec after combining stream metadata with the customer-supplied encryption key, if any.
EncryptionSpecResolutionError

Statics

S2_ENCRYPTION_KEY_HEADER