pub enum ProvisionMode {
CreateOnly {
request_token: Option<RequestToken>,
},
Ensure,
}Expand description
Mode for provisioning a resource.
Provisioning either creates a new resource with create-only semantics, or ensures that a resource exists with the requested config.
Variants
CreateOnly
Create a new resource only.
HTTP POST semantics: idempotent if a request token is provided and the resource was previously created using the same token and config.
Fields

request_token: Option<RequestToken>Optional request token used to make create retries idempotent.
Ensure
Ensure a resource exists with the requested config.
HTTP PUT semantics: always idempotent. Defaults are applied before validation. When the resource already exists, its stored config is set to the effective requested config unless it already matches.